""" Tests to confirm our fake archive service functions as intended """

# pylint: disable=E0402, W0511

from datafetcher.locations_report_refactor import LocationsReportRefactor

from .fake_archive_service import FakeArchiveService

# TODO: move this to appropriate DF test module
# def test_gets_df_settings():
#     capo = CapoConfig(profile=PROFILE)
#     key = "edu.nrao.archive.datafetcher.DataFetcherSettings"
#     field = "locatorServiceUrlPrefix"
#     to_get = key + "." + field
#     try:
#         url = capo.get(to_get)
#     except KeyError as k_err:
#         raise MissingSettingsException(f'missing required setting "{field}"') from k_err
#     assert "locator" in url
#
#


def test_service_returns_vla_eb_locations():

    """
    Does FakeArchiveService return the calibrations locations report in
    test_data?

    :return:
    """

    found = False
    report = FakeArchiveService("uid://evla/execblock/123a-456-b-789z").get_locations_report()

    assert len(report.servers_report) == 2
    assert len(report.files_report["files"]) == 79

    expected_ngas_id = "17A-109_2017_02_11_T18_49_09.756.tar"
    rel_path = None
    for file_spec in report.files_report["files"]:
        if file_spec["ngas_file_id"] == expected_ngas_id:
            found = True
            rel_path = file_spec["relative_path"]
            break
    assert found
    assert rel_path == expected_ngas_id


def test_service_returns_vlba_locations():

    """
    Does FakeArchiveService return the calibrations locations report in
    test_data?

    :return:
    """

    report = FakeArchiveService("uid://evla/vlba/uuid-du-jour31").get_locations_report()

    assert len(report.servers_report) == 1
    assert len(report.files_report["files"]) == 16

    expected_agg_size = 2140560000
    actual_agg_size = report.files_report["aggregate_size"]
    assert actual_agg_size == expected_agg_size


def test_service_returns_cal_locations():

    """
    Does FakeArchiveService return the calibrations locations report in
    test_data?

    :return:
    """

    found = False
    report = FakeArchiveService("uid://evla/calibration/different-uuid").get_locations_report()

    assert len(report.servers_report) == 1
    assert len(report.files_report) == 2

    expected_subdir = "18B-265_2019_12_10_T00_00_59.203.tar"
    for file_spec in report.files_report["files"]:
        if file_spec["subdirectory"] == expected_subdir:
            found = True
            break
    assert found


def test_service_returns_image_locations():

    """
    Does FakeArchiveService return the image locations report in test_data?

    :return:
    """

    report = FakeArchiveService("uid://evla/image/some-uuid").get_locations_report()
    assert isinstance(report, LocationsReportRefactor)
    assert len(report.servers_report) == 2
    assert len(report.files_report) == 2

    expected_file_id = "uid____evla_image_56a10be7-f1c2-4788-8651-6ecc5bfbc2f1.fits"
    found = False
    for file_spec in report.files_report["files"]:
        if file_spec["ngas_file_id"] == expected_file_id:
            found = True
            break
    assert found
